@@ -86,7 +86,7 @@ class CtrTests(unittest.TestCase):
         # Nonce attribute is not defined if suffix is used in Counter
         counter = Counter.new(64, prefix=self.nonce_32, suffix=self.nonce_32)
         cipher = AES.new(self.key_128, AES.MODE_CTR, counter=counter)
-        self.failIf(hasattr(cipher, "nonce"))
+        self.assertFalse(hasattr(cipher, "nonce"))
 
     def test_nonce_parameter(self):
         # Nonce parameter becomes nonce attribute
@@ -278,58 +278,55 @@ class CtrTests(unittest.TestCase):
 
     def test_output_param(self):
 
-        pt = b'5' * 16
+        pt = b'5' * 128
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         ct = cipher.encrypt(pt)
 
-        output = bytearray(16)
+        output = bytearray(128)
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         res = cipher.encrypt(pt, output=output)
         self.assertEqual(ct, output)
         self.assertEqual(res, None)
-        
+
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         res = cipher.decrypt(ct, output=output)
         self.assertEqual(pt, output)
         self.assertEqual(res, None)
 
     def test_output_param_memoryview(self):
-        
-        pt = b'5' * 16
+
+        pt = b'5' * 128
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         ct = cipher.encrypt(pt)
 
-        output = memoryview(bytearray(16))
+        output = memoryview(bytearray(128))
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         cipher.encrypt(pt, output=output)
         self.assertEqual(ct, output)
-        
+
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         cipher.decrypt(ct, output=output)
         self.assertEqual(pt, output)
 
     def test_output_param_neg(self):
+        LEN_PT = 128
 
-        pt = b'5' * 16
+        pt = b'5' * LEN_PT
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         ct = cipher.encrypt(pt)
 
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
-        self.assertRaises(TypeError, cipher.encrypt, pt, output=b'0'*16)
-        
-        cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
-        self.assertRaises(TypeError, cipher.decrypt, ct, output=b'0'*16)
+        self.assertRaises(TypeError, cipher.encrypt, pt, output=b'0' * LEN_PT)
 
-        shorter_output = bytearray(15)
+        cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
+        self.assertRaises(TypeError, cipher.decrypt, ct, output=b'0' * LEN_PT)
+
+        shorter_output = bytearray(LEN_PT - 1)
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         self.assertRaises(ValueError, cipher.encrypt, pt, output=shorter_output)
         cipher = AES.new(b'4'*16, AES.MODE_CTR, nonce=self.nonce_64)
         self.assertRaises(ValueError, cipher.decrypt, ct, output=shorter_output)
 
-    import sys
-    if sys.version[:3] == "2.6":
-        del test_output_param_memoryview
-
 
 class SP800TestVectors(unittest.TestCase):
     """Class exercising the CTR test vectors found in Section F.5
